<?php # $Id: lang_en.inc.php 2517 2009-06-01 02:36:52Z brockhaus $

/**
 *  @version $Revision: 2517 $
 *  @author Translator Name <yourmail@example.com>
 *  EN-Revision: Revision of lang_en.inc.php
 */

@define('PLUGIN_SHOUTBOX_NAME', 'Shoutbox');
@define('PLUGIN_SHOUTBOX_DELETE', 'Delete');
@define('PLUGIN_SHOUTBOX_SUBMIT', 'Shout it out');
@define('PLUGIN_SHOUTBOX_BLAHBLAH', 'Displays a shoutbox for unrelated comments');
@define('PLUGIN_SHOUTBOX_WORDWRAP', 'Wordwrap');
@define('PLUGIN_SHOUTBOX_WORDWRAP_BLAHBLAH', 'How many chars until a wordwrap will occur? (Default: 30)');
@define('PLUGIN_SHOUTBOX_MAXCHARS', 'Maximum chars per comment');
@define('PLUGIN_SHOUTBOX_MAXCHARS_BLAHBLAH', 'How many chars will be displayed for each comment? (Default: 120)');
@define('PLUGIN_SHOUTBOX_MAXENTRIES', 'Maximum number of comments');
@define('PLUGIN_SHOUTBOX_MAXENTRIES_BLAHBLAH', 'How many comments will be shown? (Default: 15)');

@define('GENERAL_PLUGIN_BOX_COLS', 	'Shoutbox columns');
@define('GENERAL_PLUGIN_BOX_COLS_BLAHBLAH', 	'Column count of the shoutbox input element.');
@define('GENERAL_PLUGIN_BOX_ROWS', 	'Shoutbox rows');
@define('GENERAL_PLUGIN_BOX_ROWS_BLAHBLAH', 	'Row count of thesShoutbox input element.');
?>
